==> haskell-decimal-0.5.1-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Decimal
version:              0.5.1
visibility:           public
id:                   Decimal-0.5.1-Lx1BzEmtAUnLf9W7W1l2Fx
key:                  Decimal-0.5.1-Lx1BzEmtAUnLf9W7W1l2Fx
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  00aac76c5d38552fecff8adfce28a965
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/Decimal-0.5.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/Decimal-0.5.1
hs-libraries:         HSDecimal-0.5.1-Lx1BzEmtAUnLf9W7W1l2Fx
depends:              base-4.14.0.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.1-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Decimal
version:              0.5.1
visibility:           public
id:                   Decimal-0.5.1-2jxtHbIVQ43A2etK1CsSll
key:                  Decimal-0.5.1-2jxtHbIVQ43A2etK1CsSll
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  c88317c0ea55dc5f5c8f91e004e6b371
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/Decimal-0.5.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/Decimal-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/Decimal-0.5.1
hs-libraries:         HSDecimal-0.5.1-2jxtHbIVQ43A2etK1CsSll
depends:              base-4.14.0.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
